@@ -9,5 +9,7 @@ Email: matt.c.jones.aoe@gmail.com
 :license: MIT License, see LICENSE for more details.
 """
 
-__author__ = "Matthew C. Jones"
-__version__ = "21.12"
+from .version import __version__
+
+# 2022-04-15: aeroutils was rebranded, so importing all from new package
+from flightcondition import *
